package br.com.elife.beans;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;

import org.hibernate.Criteria;
import org.hibernate.criterion.Order;
import org.hibernate.criterion.Projections;
import org.hibernate.criterion.Restrictions;

import twitter4j.Tweet;
import twitter4j.User;
import br.com.elife.exceptions.RateLimitStatisException;
import br.com.elife.model.TweetInformation;
import br.com.elife.model.TwitterUser;
import br.com.elife.persistence.ProjectDAO;
import br.com.elife.persistence.ProjectDAOLocal;
import br.com.elife.util.TwitterUtil;

/**
 * Backing Bean para a página de busca.
 * @author junior
 *
 */
public class SearchBean {
	
	private String brand;
	private Date since;
	private Integer rpp;
	private List<TwitterUser> resultList;
	private ProjectDAOLocal dao = new ProjectDAO();
	
	public String search() {
		if (rpp == null || rpp <= 0)
			rpp = 20;
		
		for (Tweet t : TwitterUtil.search(getBrand(), getRpp(), getSince())) {
			TweetInformation info = new TweetInformation();
			
			TwitterUser author;
			try {
				author = createUser(t.getFromUser());
			} catch (RateLimitStatisException e) {
				return "error";
			}
			
			TwitterUser storedUser = dao.find(TwitterUser.class, author.getLogin());
			if (storedUser == null) {
				info.setAuthor(author);
				dao.persist(author);
			} else {
				storedUser.setFollowers(author.getFollowers());
				storedUser.setFollowing(author.getFollowing());
				storedUser.setTweets(author.getTweets());
				info.setAuthor(storedUser);
				dao.update(storedUser);
			}
			info.setBrand(getBrand());
			info.setTweet(t.getText());
			info.setTweetIdentifier(t.getId());
			
			dao.persist(info);
		}
		updateResult(null);
		return "";
	}
	
	private TwitterUser createUser(String author) {
		User u = TwitterUtil.getUser(author);
		TwitterUser user = new TwitterUser();
		user.setLogin(author);
		user.setFollowers(u.getFollowersCount());
		user.setFollowing(u.getFriendsCount());
		user.setTweets(u.getStatusesCount());
		return user;
	}
	
	@SuppressWarnings("unchecked")
	public void updateResult(String orderBy) {
		Criteria c = dao.createCriteria(TweetInformation.class);
		c.setProjection(Projections.property("author"));
		c.add(Restrictions.eq("brand", getBrand()));
		if (!isEmpty(orderBy)) {
			c.createAlias("author", "a");
			c.addOrder(Order.desc("a." + orderBy));
		}
		resultList = new ArrayList<TwitterUser>(c.list());
	}
	
	public List<TwitterUser> getUsers() {
		return resultList;
	}
	
	public String getBrand() {
		return brand;
	}

	public void setBrand(String brand) {
		this.brand = brand;
	}
	
	public Date getSince() {
		return since;
	}
	
	public void setSince(Date since) {
		this.since = since;
	}
	
	public Integer getRpp() {
		return rpp;
	}
	
	public void setRpp(Integer rpp) {
		this.rpp = rpp;
	}
	
	public Integer getMaxValue() {
		return Integer.MAX_VALUE;
	}
	
	private boolean isEmpty(String s) {
		return s == null || s.trim().isEmpty();
	}
	
}
