package br.com.elife.persistence;

import java.io.Serializable;
import java.util.List;

import org.hibernate.Criteria;
import org.hibernate.HibernateException;
import org.hibernate.Session;
import org.hibernate.Transaction;

import br.com.elife.util.HibernateUtil;

public class ProjectDAO implements ProjectDAOLocal {

	private Session session = null;
	private Transaction transaction = null;

	public boolean persist(Object entity) {
		boolean result = false;
		try {
			session = HibernateUtil.getSession();
			transaction = session.beginTransaction();
			session.persist(entity);
			transaction.commit();
			result = true;
		} catch (HibernateException e) {
			transaction.rollback();
		} finally {
			if (session != null)
				session.close();
		}
		return result;
	}

	public boolean update(Object entity) {
		boolean result = false;
		try {
			session = HibernateUtil.getSession();
			transaction = session.beginTransaction();
			session.update(entity);
			transaction.commit();
			result = true;
		} catch (HibernateException e) {
			transaction.rollback();
			e.printStackTrace();
		} finally {
			if (session != null)
				session.close();
		}
		return result;
	}

	public boolean delete(Object entity) {
		boolean result = false;
		try {
			session = HibernateUtil.getSession();
			transaction = session.beginTransaction();
			session.delete(entity);
			transaction.commit();
			result = true;
		} catch (HibernateException e) {
			transaction.rollback();
			e.printStackTrace();
		} finally {
			if (session != null)
				session.close();
		}
		return result;
	}

	@SuppressWarnings("unchecked")
	public <T> T find(Class<T> entityClass, Serializable id) {
		T foundEntity = null;
		try {
			session = HibernateUtil.getSession();
			foundEntity = (T) session.get(entityClass, id);
		} catch (HibernateException e) {
			e.printStackTrace();
		} finally {
			if (session != null)
				session.close();
		}
		return foundEntity;
	}

	@SuppressWarnings("unchecked")
	public <T> List<T> findAll(Class<T> entityClass) {
		List<T> list = null;
		try {
			session = HibernateUtil.getSession();
			list = (List<T>) session.createQuery("From " + entityClass.getName()).list();
		} catch (HibernateException e) {
			e.printStackTrace();
		} finally {
			if (session != null)
				session.close();
		}
		return list;
	}
	
	public <T> Criteria createCriteria(Class<T> entityClass) {
		Criteria c = null;
		try {
			session = HibernateUtil.getSession();
			c = session.createCriteria(entityClass);
		} catch (HibernateException e) {
		} finally {
//			if (session != null)
//				session.close();
		}
		return c;
	}

}
