package br.com.elife.util;

import java.io.File;
import java.util.Arrays;

import org.hibernate.HibernateException;
import org.hibernate.Session;
import org.hibernate.SessionFactory;
import org.hibernate.cfg.AnnotationConfiguration;

import br.com.elife.model.TweetInformation;
import br.com.elife.model.TwitterUser;

/**
 * Classe utilitaria que levanta o hibernate. HIBERNATE_CFG_XML define as configuracoes, valores
 * default para um postgres com um DB de nome 'marcas', usuario de nome 'elife' e senha '3l1f3':
 * 
 * <property name="hibernate.dialect">org.hibernate.dialect.PostgreSQLDialect</property> 
 * <property name="hibernate.connection.driver_class">org.postgresql.Driver</property>
 * <property name="hibernate.connection.url">jdbc:postgresql://localhost:5432/marcas</property>
 * <property name="hibernate.connection.username">elife</property>
 * <property name="hibernate.connection.password">3l1f3</property>
 * <property name="hibernate.show_sql">true</property>
 * <property name="hibernate.hbm2ddl.auto">create-drop</property>
 * 
 * @author Demontie Junior
 * 
 */
public class HibernateUtil {

	private static final String HIBERNATE_CFG_XML = "hibernate.cfg.xml";
	private static final SessionFactory sessionFactory;
	static {
		try {
			System.out.println(Arrays.toString(new File(".").list()));
			AnnotationConfiguration cfg = new AnnotationConfiguration().addResource(HIBERNATE_CFG_XML);
			
			//adicione as classes persistentes aqui
			cfg.addAnnotatedClass(TweetInformation.class);
			cfg.addAnnotatedClass(TwitterUser.class);
			
			sessionFactory = cfg.configure().buildSessionFactory();
		} catch (Throwable ex) {
			ex.printStackTrace();
			throw new ExceptionInInitializerError(ex);
		}
	}

	public static Session getSession() throws HibernateException {
		return sessionFactory.openSession();
	}

	public static Session getCurrentSession() throws HibernateException {
		return sessionFactory.getCurrentSession();
	}

}