package br.com.elife.util;

import java.util.Calendar;
import java.util.Collections;
import java.util.Date;
import java.util.List;

import javax.faces.application.FacesMessage;
import javax.faces.context.FacesContext;

import twitter4j.Query;
import twitter4j.QueryResult;
import twitter4j.RateLimitStatus;
import twitter4j.RateLimitStatusEvent;
import twitter4j.RateLimitStatusListener;
import twitter4j.Tweet;
import twitter4j.Twitter;
import twitter4j.TwitterException;
import twitter4j.TwitterFactory;
import twitter4j.User;
import br.com.elife.exceptions.RateLimitStatisException;

/**
 * Interface de comunicacao com o Twitter.
 * 
 * @author Demontie Junior
 *
 */
public class TwitterUtil {

	public static List<Tweet> search(String brand, Integer rpp, Date since) {
		Twitter twitter = new TwitterFactory().getInstance();
		twitter.addRateLimitStatusListener(new RateLimitStatisListenerImpl());
		Query query = new Query("source: " + brand);
		query.setRpp(rpp != null && rpp > 0 ? rpp : 20);
		if (since != null) {
			Calendar sinceCalendar = Calendar.getInstance();
			sinceCalendar.setTime(since);
			query.setSince(String.format("%d-%d-%d", 
					sinceCalendar.get(Calendar.YEAR),
					sinceCalendar.get(Calendar.MONTH),
					sinceCalendar.get(Calendar.DAY_OF_MONTH)));
		}
		QueryResult result;
		try {
			result = twitter.search(query);
			return result.getTweets();
		} catch (TwitterException e) {
		}
		return Collections.emptyList();
	}
	
	public static User getUser(String userLogin) {
		Twitter twitter = new TwitterFactory().getInstance();
		twitter.addRateLimitStatusListener(new RateLimitStatisListenerImpl());
		try {
			return twitter.showUser(userLogin);
		} catch (TwitterException e) {
		}
		return null;
	}
	
	private static class RateLimitStatisListenerImpl implements RateLimitStatusListener {
		
		public void onRateLimitStatus(RateLimitStatusEvent event) {
			RateLimitStatus rateLimitStatus = event.getRateLimitStatus();
			if (rateLimitStatus.getRemainingHits() <= 0) {
				FacesContext.getCurrentInstance().addMessage(null,
						new FacesMessage("Taxa limite de pesquisa excedida. Tente novamente em " 
								+ rateLimitStatus.getSecondsUntilReset() + " segundos."));
				throw new RateLimitStatisException();
			}
		}
		
		public void onRateLimitReached(RateLimitStatusEvent event) {
		}
	}
	
}
